@@ -1,6 +1,6 @@
 # vim: set fileencoding=utf-8:
 # GNU Solfege - free ear training software
-# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008  Tom Cato Amundsen
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2011  Tom Cato Amundsen
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -213,9 +213,9 @@ class SolfegeApp(cfg.ConfigUtils):
             else:
                 if solfege.splash_win:
                     solfege.splash_win.hide()
-                gu.dialog_ok(_("The pyalsa python module is missing"),
+                gu.dialog_ok(_("The pyalsa Python module is missing"),
                     solfege.win,
-                    _("Solfege was configured to the Python modules from www.alsa-project.org, but the modules was not found. You must reconfigure sound in the preferences window (Ctrl-F12) or restart Solfege in a way that it finds the module."))
+                    _("Solfege was configured to use the Python modules from www.alsa-project.org, but the modules were not found. You must reconfigure sound in the preferences window (Ctrl-F12) or restart Solfege in a way that it finds the modules."))
                 soundcard.initialise_using_fake_synth(True)
                 if solfege.splash_win:
                     solfege.splash_win.show()
@@ -388,10 +388,6 @@ class SolfegeApp(cfg.ConfigUtils):
             solfege.win.get_view().on_end_practise()
             solfege.win.get_view().on_start_practise()
     def quit_program(self):
-        try:
-            cfg.sync()
-        except IOError, e:
-            gu.display_exception_message(e)
         if isinstance(solfege.win.get_view(), abstract.Gui):
             g = solfege.win.get_view()
             # Check that the lesson file has a header, because if the
@@ -400,6 +396,10 @@ class SolfegeApp(cfg.ConfigUtils):
             # exceptions.
             if g.m_t.m_P and getattr(g.m_t.m_P, 'header', None):
                 g.on_end_practise()
+        try:
+            cfg.sync()
+        except IOError, e:
+            gu.display_exception_message(e)
         try:
             solfege.db.conn.commit()
         except sqlite3.ProgrammingError, e:
