@@ -111,8 +111,7 @@ class Gui(abstract.LessonbasedGui):
         ##############
         # statistics #
         ##############
-        self.setup_statisticsviewer(statisticsviewer.PercentagesStatisticsViewer,
-                                   _("elembuilder"))
+        self.setup_statisticsviewer(statisticsviewer.PercentagesStatisticsViewer, "")
     def new_question(self, widget):
         self.g_answer.foreach(lambda w: w.destroy())
         self.m_users_answer = []
